@@ -10,12 +10,12 @@ use Pcore::CDN;
 has cfg   => ( required => 1 );    # HashRef
 has devel => 0;                    # Bool
 
+has name   => ( init_arg => undef );
 has server => ( init_arg => undef );    # InstanceOf ['Pcore::HTTP::Server']
-has router => ( init_arg => undef );    # InstanceOf ['Pcore::App::Router']
+has router => ( init_arg => undef );    # HashRef [ InstanceOf ['Pcore::App::Router'] ]
 has api    => ( init_arg => undef );    # Maybe [ InstanceOf ['Pcore::App::API'] ]
 has node   => ( init_arg => undef );    # InstanceOf ['Pcore::Node']
 has cdn    => ( init_arg => undef );    # InstanceOf['Pcore::CDN']
-has ext    => ( init_arg => undef );    # InstanceOf['Pcore::Ext']
 
 const our $PERMS_ADMIN => 'admin';
 const our $PERMS_USER  => 'user';
@@ -29,13 +29,27 @@ const our $LOCALES => {
 
 };
 
-sub BUILD ( $self, $args ) {
+sub merge_config ( $self, $app_cfg, $cfg ) {
 
-    # create HTTP router
-    $self->{router} = Pcore::App::Router->new( {
-        app   => $self,
-        hosts => $self->{cfg}->{router},
-    } );
+    # merge server config
+    for my $server ( keys $app_cfg->{cfg}->{server}->%* ) {
+
+        # listen
+        if ( my $listen = $cfg->{server}->{$server}->{listen} ) {
+            $app_cfg->{cfg}->{server}->{$server}->{listen} = $listen;
+        }
+
+        # server_name
+        if ( my $server_name = $cfg->{server}->{$server}->{server_name} ) {
+            push $app_cfg->{cfg}->{server}->{$server}->{server_name}->@*, P->scalar->is_plain_arrayref($server_name) ? $server_name->@* : $server_name;
+        }
+    }
+
+    return;
+}
+
+sub BUILD ( $self, $args ) {
+    $self->{name} = lc( ref $self ) =~ s/::/-/smgr;
 
     # create CDN object
     $self->{cdn} = Pcore::CDN->new( $self->{cfg}->{cdn} ) if $self->{cfg}->{cdn};
@@ -105,76 +119,63 @@ around run => sub ( $orig, $self ) {
     say 'API initialization ... ' . $res;
     exit 3 if !$res;
 
-    # scan HTTP controllers
-    print 'Scanning HTTP controllers ... ';
-    $self->{router}->init;
-    say 'done';
+    # create HTTP routers
+    for my $name ( sort keys $self->{cfg}->{server}->%* ) {
+        print "Scanning HTTP controllers $name ... ";
+
+        $self->{router}->{$name} = Pcore::App::Router->new( {
+            app       => $self,
+            namespace => $self->{cfg}->{server}->{$name}->{namespace},
+        } );
+
+        $self->{router}->{$name}->init;
 
-    if ( defined $self->{ext} && !$self->{devel} ) {
-        print 'Clearing Ext build cache ... ';
-        $self->{ext}->clear_cache;
         say 'done';
     }
 
     $res = $self->$orig;
     exit 3 if !$res;
 
-    # start HTTP server
-    if ( defined $self->{cfg}->{server}->{listen} ) {
-        $self->{server} = Pcore::HTTP::Server->new( { $self->{cfg}->{server}->%*, on_request => $self->{router} } );
+    # start HTTP servers
+    for my $name ( sort keys $self->{cfg}->{server}->%* ) {
+        $self->{cfg}->{server}->{$name}->{listen} ||= "/var/run/$self->{name}-$name.sock";
 
-        say qq[Listen: $self->{cfg}->{server}->{listen}];
+        my $http_server = Pcore::HTTP::Server->new( {
+            listen     => $self->{cfg}->{server}->{$name}->{listen},
+            on_request => $self->{router}->{$name},
+        } );
+
+        $self->{server}->{$name} = $http_server;
+
+        say qq[Listen "$name": $http_server->{listen}];
     }
 
-    say qq[App "@{[ref $self]}" started];
+    say qq[App "$self->{name}" started];
 
     return;
 };
 
 # NGINX
-sub nginx_params ($self) {
-    my $params = {
-        name              => lc( ref $self ) =~ s/::/-/smgr,
-        data_dir          => $ENV->{DATA_DIR},
-        root_dir          => undef,                                                                  # TODO
-        default_server    => 1,                                                                      # generate default server config
-        nginx_default_key => $ENV->{share}->get('data/nginx/default.key'),
-        nginx_default_pem => $ENV->{share}->get('data/nginx/default.pem'),
-        upstream          => P->uri( $self->{cfg}->{server}->{listen} )->to_nginx_upstream_server,
-    };
+sub start_nginx ($self) {
+    my $nginx = $self->{nginx} = Pcore::API::Nginx->new;
 
-    for my $host ( keys $self->{router}->{path_ctrl}->%* ) {
-        my $host_name;
+    $nginx->remove_vhosts;
 
-        if ( $host eq '*' ) {
-            $params->{default_server} = 0;
+    my $has_server_name;
 
-            $host_name = q[""];
+    for my $vhost_name ( sort keys $self->{cfg}->{server}->%* ) {
+        my $vhost_params = $self->get_nginx_vhost_params($vhost_name);
+
+        $nginx->add_vhost( $vhost_name, $vhost_params );    # if !$nginx->is_vhost_exists($vhost_name);
+
+        if ( $self->{cfg}->{server}->{$vhost_name}->{server_name} && $self->{cfg}->{server}->{$vhost_name}->{server_name}->@* ) {
+            $has_server_name = 1;
+
+            $nginx->add_load_balancer_vhost( "$self->{name}-$vhost_name", $vhost_params );
         }
-        else {
-            $host_name = $host;
-        }
-
-        for my $path ( keys $self->{router}->{path_ctrl}->{$host}->%* ) {
-            my $ctrl = $self->{router}->{path_ctrl}->{$host}->{$path};
-
-            push $params->{host}->{$host_name}->{location}->@*, $ctrl->get_nginx_cfg;
-        }
-
-        push $params->{host}->{$host_name}->{location}->@*, $self->{cdn}->get_nginx_cfg if defined $self->{cdn};
     }
 
-    return $params;
-}
-
-sub start_nginx ($self) {
-    my $name = lc( ref $self ) =~ s/::/-/smgr;
-
-    $self->{nginx} = Pcore::API::Nginx->new;
-
-    $self->{nginx}->add_vhost( $name, $self->nginx_params );    # if !$self->{nginx}->is_vhost_exists('vhost');
-
-    $self->{nginx}->add_load_balancer_vhost( $name, { server_name => $self->{cfg}->{load_balancer}->{server_name} } ) if $self->{cfg}->{load_balancer}->{server_name};
+    $nginx->add_default_vhost if $has_server_name;
 
     # SIGNUP -> nginx reload
     $SIG->{HUP} = AE::signal HUP => sub {
@@ -187,11 +188,31 @@ sub start_nginx ($self) {
         return;
     };
 
-    $self->{nginx}->run;
+    $nginx->run;
 
     return;
 }
 
+sub get_nginx_vhost_params ( $self, $vhost_name ) {
+    my $params = {
+        app_name    => $self->{name},
+        vhost_name  => $vhost_name,
+        server_name => $self->{cfg}->{server}->{$vhost_name}->{server_name},
+        data_dir    => $ENV->{DATA_DIR},
+        upstream    => $self->{server}->{$vhost_name}->{listen}->to_nginx_upstream_server,
+    };
+
+    for my $path ( sort keys $self->{router}->{$vhost_name}->{path_ctrl}->%* ) {
+        my $ctrl = $self->{router}->{$vhost_name}->{path_ctrl}->{$path};
+
+        push $params->{locations}->@*, $ctrl->get_nginx_cfg;
+    }
+
+    push $params->{locations}->@*, $self->{cdn}->get_nginx_cfg if defined $self->{cdn};
+
+    return $params;
+}
+
 1;
 __END__
 =pod
