@@ -1,9 +1,13 @@
 package Pcore::App::API::Backend::NoAuth;
 
-use Pcore -role;
+use Pcore -class, -res;
 
 with qw[Pcore::App::API];
 
+sub init ($self) {
+    return res 200;
+}
+
 1;
 __END__
 =pod
